==> buffer-from-buffer-0.0.6.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# copyBuffer

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Copy [buffer][@stdlib/buffer/ctor] data to a new [`Buffer`][@stdlib/buffer/ctor] instance.

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/buffer-from-buffer
```

</section>

<section class="usage">

## Usage

```javascript
var copyBuffer = require( '@stdlib/buffer-from-buffer' );
```

#### copyBuffer( buffer )

Copies [buffer][@stdlib/buffer/ctor] data to a new [`Buffer`][@stdlib/buffer/ctor] instance.

```javascript
var array2buffer = require( '@stdlib/buffer-from-array' );

var b1 = array2buffer( [ 1, 2, 3, 4 ] );
// returns <Buffer>[ 1, 2, 3, 4 ]

var b2 = copyBuffer( b1 );
// returns <Buffer>[ 1, 2, 3, 4 ]
```

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var allocUnsafe = require( '@stdlib/buffer-alloc-unsafe' );
var copyBuffer = require( '@stdlib/buffer-from-buffer' );

var bool;
var b1;
var b2;
var i;

// Allocate a new buffer:
b1 = allocUnsafe( 10 );

// Generate a new buffer from the existing buffer:
b2 = copyBuffer( b1 );

bool = ( b2 === b1 );
// returns false

bool = ( b2.length === b1.length );
// returns true

for ( i = 0; i < b2.length; i++ ) {
    console.log( b2[ i ] === b1[ i ] );
    // => true
}
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/buffer-from-buffer.svg
[npm-url]: https://npmjs.org/package/@stdlib/buffer-from-buffer

[test-image]: https://github.com/stdlib-js/buffer-from-buffer/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/buffer-from-buffer/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/buffer-from-buffer/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/buffer-from-buffer?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/buffer-from-buffer.svg
[dependencies-url]: https://david-dm.org/stdlib-js/buffer-from-buffer/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/buffer-from-buffer/main/LICENSE

[@stdlib/buffer/ctor]: https://www.npmjs.com/package/@stdlib/buffer-ctor

</section>

<!-- /.links -->

==> buffer-from-buffer-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# copyBuffer

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Copy [buffer][@stdlib/buffer/ctor] data to a new [`Buffer`][@stdlib/buffer/ctor] instance.

<!-- Section to include introductory text. Make sure to keep an empty line after the intro `section` element and another before the `/section` close. -->

<section class="intro">

</section>

<!-- /.intro -->

<!-- Package usage documentation. -->

<section class="installation">

## Installation

```bash
npm install @stdlib/buffer-from-buffer
```

</section>

<section class="usage">

## Usage

```javascript
var copyBuffer = require( '@stdlib/buffer-from-buffer' );
```

#### copyBuffer( buffer )

Copies [buffer][@stdlib/buffer/ctor] data to a new [`Buffer`][@stdlib/buffer/ctor] instance.

```javascript
var array2buffer = require( '@stdlib/buffer-from-array' );

var b1 = array2buffer( [ 1, 2, 3, 4 ] );
// returns <Buffer>[ 1, 2, 3, 4 ]

var b2 = copyBuffer( b1 );
// returns <Buffer>[ 1, 2, 3, 4 ]
```

</section>

<!-- /.usage -->

<!-- Package usage notes. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="notes">

</section>

<!-- /.notes -->

<!-- Package usage examples. -->

<section class="examples">

## Examples

<!-- eslint no-undef: "error" -->

```javascript
var allocUnsafe = require( '@stdlib/buffer-alloc-unsafe' );
var copyBuffer = require( '@stdlib/buffer-from-buffer' );

var bool;
var b1;
var b2;
var i;

// Allocate a new buffer:
b1 = allocUnsafe( 10 );

// Generate a new buffer from the existing buffer:
b2 = copyBuffer( b1 );

bool = ( b2 === b1 );
// returns false

bool = ( b2.length === b1.length );
// returns true

for ( i = 0; i < b2.length; i++ ) {
    console.log( b2[ i ] === b1[ i ] );
    // => true
}
```

</section>

<!-- /.examples -->

<!-- Section to include cited references. If references are included, add a horizontal rule *before* the section. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="references">

</section>

<!-- /.references -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/buffer/alloc-unsafe`][@stdlib/buffer/alloc-unsafe]</span><span class="delimiter">: </span><span class="description">allocate a buffer having a specified number of bytes.</span>
-   <span class="package-name">[`@stdlib/buffer/ctor`][@stdlib/buffer/ctor]</span><span class="delimiter">: </span><span class="description">Buffer.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/buffer-from-buffer.svg
[npm-url]: https://npmjs.org/package/@stdlib/buffer-from-buffer

[test-image]: https://github.com/stdlib-js/buffer-from-buffer/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/buffer-from-buffer/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/buffer-from-buffer/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/buffer-from-buffer?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/buffer-from-buffer.svg
[dependencies-url]: https://david-dm.org/stdlib-js/buffer-from-buffer/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/buffer-from-buffer/tree/deno
[umd-url]: https://github.com/stdlib-js/buffer-from-buffer/tree/umd
[esm-url]: https://github.com/stdlib-js/buffer-from-buffer/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/buffer-from-buffer/main/LICENSE

<!-- <related-links> -->

[@stdlib/buffer/alloc-unsafe]: https://www.npmjs.com/package/@stdlib/buffer-alloc-unsafe

[@stdlib/buffer/ctor]: https://www.npmjs.com/package/@stdlib/buffer-ctor

<!-- </related-links> -->

</section>

<!-- /.links -->
